import 'dart:convert';

import 'user.dart';

class Session {
  final String accessToken;
  final int? expiresIn;
  final String? refreshToken;
  final String? tokenType;
  final User? user;

  Session({
    required this.accessToken,
    required this.expiresIn,
    required this.refreshToken,
    required this.tokenType,
    required this.user,
  });

  factory Session.fromJson(Map<String, dynamic> json) => Session(
        accessToken: json['access_token'] as String,
        expiresIn: json['expires_in'] as int,
        refreshToken: json['refresh_token'] as String?,
        tokenType: json['token_type'] as String?,
        user: json['user'] != null
            ? User.fromJson(json['user'] as Map<String, dynamic>)
            : null,
      );

  Map<String, dynamic> toJson() => {
        'access_token': accessToken,
        'expires_in': expiresIn,
        'refresh_token': refreshToken,
        'token_type': tokenType,
        'user': user?.toJson(),
      };

  String get persistSessionString {
    final timeNow = (DateTime.now().millisecondsSinceEpoch / 1000).round();
    final expiresAt = timeNow + expiresIn!;
    final data = {'currentSession': toJson(), 'expiresAt': expiresAt};
    return json.encode(data);
  }
}
